pub struct BlockerMeta {
pub id: String,
pub severity: Option<String>,
pub owner: Option<String>,
pub status: Option<String>,
}Fields
id: Stringseverity: Option<String>owner: Option<String>status: Option<String>Trait Implementations
Sourceimpl Clone for BlockerMeta
impl Clone for BlockerMeta
Sourcefn clone(&self) -> BlockerMeta
fn clone(&self) -> BlockerMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockerMeta
impl Debug for BlockerMeta
Sourceimpl<'de> Deserialize<'de> for BlockerMeta
impl<'de> Deserialize<'de> for BlockerMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BlockerMeta
impl JsonSchema for BlockerMeta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BlockerMeta
impl PartialEq for BlockerMeta
Sourcefn eq(&self, other: &BlockerMeta) -> bool
fn eq(&self, other: &BlockerMeta) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BlockerMeta
impl Serialize for BlockerMeta
impl StructuralPartialEq for BlockerMeta