pub struct ChangeMeta {
pub files: Vec<String>,
pub scope: Option<String>,
}Fields
files: Vec<String>scope: Option<String>Trait Implementations
Sourceimpl Clone for ChangeMeta
impl Clone for ChangeMeta
Sourcefn clone(&self) -> ChangeMeta
fn clone(&self) -> ChangeMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChangeMeta
impl Debug for ChangeMeta
Sourceimpl<'de> Deserialize<'de> for ChangeMeta
impl<'de> Deserialize<'de> for ChangeMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChangeMeta
impl JsonSchema for ChangeMeta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ChangeMeta
impl PartialEq for ChangeMeta
Sourcefn eq(&self, other: &ChangeMeta) -> bool
fn eq(&self, other: &ChangeMeta) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ChangeMeta
impl Serialize for ChangeMeta
impl StructuralPartialEq for ChangeMeta