pub struct EntryMeta {
pub id: String,
pub at: String,
pub actor: String,
pub kind: EntryKind,
pub summary: String,
pub corrects: Option<String>,
pub supersedes: Option<String>,
}Fields
id: Stringat: Stringactor: Stringkind: EntryKindsummary: Stringcorrects: Option<String>supersedes: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for EntryMeta
impl<'de> Deserialize<'de> for EntryMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EntryMeta
impl JsonSchema for EntryMeta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for EntryMeta