pub struct ProgressProfileSchema {
pub progress: Option<ProgressMeta>,
pub entry: Option<EntryMeta>,
pub change: Option<ChangeMeta>,
pub test: Option<TestMeta>,
pub blocker: Option<BlockerMeta>,
pub next: Option<NextMeta>,
}Fields
progress: Option<ProgressMeta>entry: Option<EntryMeta>change: Option<ChangeMeta>test: Option<TestMeta>blocker: Option<BlockerMeta>next: Option<NextMeta>Trait Implementations
Sourceimpl Clone for ProgressProfileSchema
impl Clone for ProgressProfileSchema
Sourcefn clone(&self) -> ProgressProfileSchema
fn clone(&self) -> ProgressProfileSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressProfileSchema
impl Debug for ProgressProfileSchema
Sourceimpl<'de> Deserialize<'de> for ProgressProfileSchema
impl<'de> Deserialize<'de> for ProgressProfileSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProgressProfileSchema
impl JsonSchema for ProgressProfileSchema
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressProfileSchema
impl PartialEq for ProgressProfileSchema
Sourcefn eq(&self, other: &ProgressProfileSchema) -> bool
fn eq(&self, other: &ProgressProfileSchema) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProgressProfileSchema
impl Serialize for ProgressProfileSchema
impl StructuralPartialEq for ProgressProfileSchema